#
# spec file for package python-qt3d-qt5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# This definition is for projects which include the PyQt5 packages in recent
# versions but use default (old) Qt libraries e.g. from Leap, which does not
# have Qt >= 5.10. In that case, no Qt3DAnimation module will be built per
# sip %%If directives in the sip/Qt3DAnimation/*.sip files
%if %{pkg_vcmp libQt53DAnimation-devel >= 5.10}
%define have_qt3danimation 1
%endif

%define plainpython python
%define mname qt3d-qt5
%{?sle15_python_module_pythons}

Name:           python-%{mname}
Version:        5.15.6
Release:        2.9
Summary:        Python bindings for the Qt5 3D framework
License:        GPL-3.0-only
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/pyqtchart/intro
Source:         https://files.pythonhosted.org/packages/source/P/PyQt3D/PyQt3D-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyqt-builder >= 1.9}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module sip-devel >= 5.3}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt53DAnimation)
BuildRequires:  pkgconfig(Qt53DCore)
BuildRequires:  pkgconfig(Qt53DExtras)
BuildRequires:  pkgconfig(Qt53DInput)
BuildRequires:  pkgconfig(Qt53DLogic)
BuildRequires:  pkgconfig(Qt53DRender)
Provides:       python-PyQt3D = %{version}-%{release}
Requires:       python-qt5 >= 5.15.4
Requires:       python-qt5-sip

%python_subpackages

%description
PyQt3D is a set of Python bindings for the Qt 3D framework.

%package devel
Summary:        Development files for %{name}
Group:          Development/Tools/IDE
Requires:       python-qt5-devel
Requires:       %{plainpython}(abi) = %python_version
Supplements:    (eric and python-%{mname})
Supplements:    (python-qt5-devel and python-%{mname})
Provides:       python-%{mname}-sip = %{version}-%{release}
Obsoletes:      python-%{mname}-sip < %{version}-%{release}
Provides:       python-%{mname}-api = %{version}-%{release}
Obsoletes:      python-%{mname}-api < %{version}-%{release}
Provides:       %{plainpython}-%{mname}-sip = %{version}-%{release}
Obsoletes:      %{plainpython}-%{mname}-sip < %{version}-%{release}
Provides:       %{plainpython}-%{mname}-api = %{version}-%{release}
Obsoletes:      %{plainpython}-%{mname}-api < %{version}-%{release}

%description devel
This package provides the SIP files used to generate the Python bindings
and the Qt5 3D framework API files for the Eric IDE for %{name}

%package doc
Summary:        Examples for %{name}
Group:          Documentation/Other
Provides:       %{python_module %{mname}-examples = %{version}-%{release}}
BuildArch:      noarch

%description doc
This package provides %{name} examples.

%prep
%autosetup -p1 -n PyQt3D-%{version}

%build
%pyqt_build

%install
%pyqt_install
# replace CRLF line endings in example resources in order to make rpmlint happy.
find examples/assets -type f -print0 | xargs -0 dos2unix 
%pyqt_install_examples %mname

%files %{python_files}
%license LICENSE
%doc NEWS README
%dir %{python_sitearch}/PyQt5/
%{?have_qt3danimation:%{python_sitearch}/PyQt5/Qt3DAnimation.*}
%{python_sitearch}/PyQt5/Qt3DCore.*
%{python_sitearch}/PyQt5/Qt3DExtras.*
%{python_sitearch}/PyQt5/Qt3DInput.*
%{python_sitearch}/PyQt5/Qt3DLogic.*
%{python_sitearch}/PyQt5/Qt3DRender.*
%{python_sitearch}/PyQt3D-%{version}.dist-info/

%files %{python_files devel}
%license LICENSE
%dir %{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/PyQt3D.api
%{?have_qt3danimation:%{pyqt5_sipdir}/Qt3DAnimation/}
%{pyqt5_sipdir}/Qt3DCore/
%{pyqt5_sipdir}/Qt3DExtras/
%{pyqt5_sipdir}/Qt3DInput/
%{pyqt5_sipdir}/Qt3DLogic/
%{pyqt5_sipdir}/Qt3DRender/

%files %{python_files doc}
%license LICENSE
%{_docdir}/%{python_prefix}-%{mname}
%exclude %{_docdir}/%{python_prefix}-%{mname}/NEWS
%exclude %{_docdir}/%{python_prefix}-%{mname}/README

%changelog
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module for more modern python in 15.x
* Sun Jan 29 2023 Ben Greiner <code@bnavigator.de>
- Update to PyQt3D 5.15.6
  * Fixed building against Qt v5.15.8 and later.
- Drop qt3d-geometry-equals.patch
* Thu Jan 12 2023 Ben Greiner <code@bnavigator.de>
- Fix Timeline generation for qt3d-geometry-equals.patch
* Thu Jan 12 2023 Ben Greiner <code@bnavigator.de>
- Merge -api and -sip packages into -devel
- Add qt3d-geometry-equals.patch
  * https://www.riverbankcomputing.com/pipermail/pyqt/2023-January/045097.html
* Wed Jan 11 2023 Ben Greiner <code@bnavigator.de>
- Update to PyQt3D 5.15.5
  * Added support for Python v3.10.
* Mon Sep 13 2021 Ben Greiner <code@bnavigator.de>
- Remove the Supplements for python-sip -- boo#1190441
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Provide the PyPI name
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.4
  * Packaging bug fixes.
- Fixes problems with packages checking the package metadata like
  boo#1183144
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.15.3
  * Sync release with PyQt5
- Switch all distros to SIP v5+
- Disable Python 2 build
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.2
  * Build system changes
* Sat Sep 26 2020 Benjamin Greiner <code@bnavigator.de>
- Fix openSUSE:Leap:15.1:Update failure: Qt3DAnimation is only
  built for Qt >= 5.10
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Use sip5 where available
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 5.15.1
  * A bug-fix release.
* Wed Sep  2 2020 Benjamin Greiner <code@bnavigator.de>
- Remove the superfluous Tumbleweed python2 hack
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.0
  * Added support for Qt v5.15.0.
- v5.14.0 added support for Qt v5.14.0 in December 2019
- The source location has changed to PyPI
* Fri Mar 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building the python2 package for openSUSE Tumbleweed.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.13.1
  * Added support for SIP v5.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  Update bindings for Qt3D 5.13.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version (5.12)
